# colors

Colors is a simple library that makes it easier to use colors in fstrings.
The standard ansi colors are (in order):

- Black
- Red
- Green
- Yellow
- Blue
- Pink
- Cyan
- White

These are accessible in the following variations:

- (f)ore(g)round
- (b)ack(g)round
- (u)nder(line)d
- (bold)ed
- (f)ore(g)round_(hi)lighted
- (b)ack(g)round_(hi)lighted
- (bold)_(hi)lighted

Forground, Background, Underline, and Bold can all be chained together in any order, as:

```python3
f"{uline.blue}{bg.red}red underlined text{reset}"
```

Highlighted colors must be custom-built due to a difference in how their codes are constructed.
This can be done as so:

```python3
f"{all_hi(Color.Blue, Color.White, bold=0)}this is white on blue text, unbolded{reset}"
```

While I may end up figuring out a way around this, it will not be soon. Feel free to use these features as-is.


## Installation
```sh
$ pip3 install colors
```

or

```sh
$ python3 setup.py install
```

### License

